from openai import OpenAI
import os

# Set your API key
client = OpenAI(api_key= os.environ.get("OPENAI_API_KEY"))

def ChatGPT_API(prompt):
  # Create a request to the chat completions endpoint
  response = client.chat.completions.create(
    model="gpt-4o",
    # Assign the role and content for the message
    messages=[{"role": "user", "content": prompt}]) 
  return response.choices[0].message.content

# Create the instructions
instructions = """
Step 1 - First work out your own solution to the problem delimited by three backticks. Don't rely on the student's solution, also given delimited by three backticks after the problem statement, since it may be incorrect. Don’t specify your own solution but use it for step 2. 
Step 2 - Compare your solution to the student's solution and evaluate if the student's solution is correct or not. Again don’t show your own solution.
Step 3 - If the student made a mistake, determine what hint you could give the student without giving away the answer. Enclose all your work for this step within triple quotes. 
Step 4 - If the student made a mistake, provide the hint from the previous step to the student (outside of triple quotes). Instead of writing step 4 - ... write Hint:. 
"""

# Create the output format
output_format = """
Do not show the logical reasoning of the model, the steps described above, but showcase the following output:
Problem Statement: <insert here the problem > 
Student Solution: <insert the student solution here>
Feedback: <insert Hint or state that the solution is correct>
"""

problem = """
Problem: Most economists recommend that government stimulus programs after a major economic shock are 3T: timely,
targeted, and temporary. Motivate each one of these three T’s. For each separate T, explain what might go wrong if the program is not timely/targeted/temporary. 
"""

student_solution = """
Student Solution: 
Timely: should start quickly after shock in order to be effective. If the program starts too late, then some firms
may have gone bankrupt, jobs may have been lost, etc.
Targeted: should be aimed at the places where it is most effective. If for certain beneficiaries the value added
of the program is not high then we can speak of deadweight loss. Less targeted programs are less efficient.
Temporary: should end on time. If the program ends too late then it will hamper economic growth as creative
destruction is distorted (capital and labor are not allocated at their most productive places)
"""

# Create the final prompt
prompt = instructions + output_format + f"```{problem}```" + f"```{student_solution}"
response = ChatGPT_API(prompt)
print(response)